@@ -88,7 +88,7 @@ static const ButAction  toolPic_action = {
  * Functions
  **********************************************************************/
 void  cgbuts_init(Cgbuts *cgbuts, ButEnv *env, Rnd *rnd, int color,
-		  bool  hold, bool hiContrast)  {
+		  bool  hold, bool hiContrast, int timeWarn)  {
   MAGIC_SET(cgbuts);
 
   cgbuts->env = env;
@@ -103,6 +103,7 @@ void  cgbuts_init(Cgbuts *cgbuts, ButEnv *env, Rnd *rnd, int color,
   cgbuts->holdStart = 0;
   cgbuts->hiContrast = hiContrast;
   cgbuts->holdEnabled = hold;
+  cgbuts->timeWarn = timeWarn;
 
   butEnv_setChar(env, 1.0, CGBUTS_REWCHAR, drawRewChar, NULL);
   butEnv_setChar(env, 0.5, CGBUTS_BACKCHAR, drawBackChar, NULL);
