@@ -189,6 +189,7 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"client.look.y", "", NULL, 0, NULL},
     {"client.look.bProp", "1.0", NULL, 0, checkBProp},
     {"client.saykib", "1", NULL, 0, NULL},
+    {"client.warnLimit", "30", NULL, 0, NULL},
     {"abut.fsel.x", "", NULL, 0, NULL},
     {"abut.fsel.y", "", NULL, 0, NULL},
     {"abut.fsel.w", "1.2", NULL, 0, NULL},
@@ -280,7 +281,8 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
   butEnv_setFont(cg->env, 2, msg_bFonts, cg->fontH);
   cgbuts_init(&cg->cgbuts, cg->env, cg->rnd, color,
 	      clp_getBool(cg->clp, "client.noTypo"),
-	      clp_getBool(cg->clp, "hiContrast"));
+	      clp_getBool(cg->clp, "hiContrast"),
+	      clp_getInt(cg->clp, "client.warnLimit"));
   if (cg->cgbuts.color == GrayScale)  {
     cg->boardPixmap = butEnv_pixmap(cg->env, BUT_LIT);
   } else  {
