@@ -37,7 +37,7 @@ static void  getListEl(CliGameList *gl, int gNum, Str *out);
 static ButOut  sResize(ButWin *win);
 static ButOut  reload(But *but);
 static ButOut  listPressed(But *but, int line);
-
+static ButOut observeGame(void *packet, int boardId);
 
 /**********************************************************************
  * Functions
@@ -54,6 +54,8 @@ CliGameList  *cliGameList_init(CliGameList *gl, CliData *data,
   gl->kibGame = -1;
   gl->win = NULL;
   gl->elfBugReported = FALSE;
+  data->observeGame = observeGame;
+  data->obPacket = gl;
   return(gl);
 }
 
@@ -935,22 +937,27 @@ static ButOut  listPressed(But *but, int line)  {
 
   gl = but_packet(but);
   assert(MAGIC(gl));
-  ++line;
-  assert((line > 0) && (line < gl->maxGames));
-  if (gl->games[line].state == cliGame_noGame)
+  return(observeGame(gl, line + 1));
+}
+
+static ButOut observeGame(void *packet, int boardId) {
+  CliGameList *gl = packet;
+
+  assert(MAGIC(gl));
+  assert((boardId > 0) && (boardId < gl->maxGames));
+  if (gl->games[boardId].state == cliGame_noGame)
     return(BUTOUT_ERR);
-  if (gl->games[line].board)  {
+  if (gl->games[boardId].board)  {
     XRaiseWindow(butEnv_dpy(gl->data->cg->env),
-		 butWin_xwin(gl->games[line].board->goban->win));
-  } else if (!gl->games[line].gamePressed)  {
-    gl->games[line].gamePressed = TRUE;
-    str_print(&gl->data->cmdBuild, "observe %d\n", line);
+		 butWin_xwin(gl->games[boardId].board->goban->win));
+  } else if (!gl->games[boardId].gamePressed)  {
+    gl->games[boardId].gamePressed = TRUE;
+    str_print(&gl->data->cmdBuild, "observe %d\n", boardId);
     cliConn_send(&gl->data->conn, str_chars(&gl->data->cmdBuild));
   }
   return(0);
 }
 
-
 bool cliGame_tellIsSay(CliGameList *list, Str *tell)  {
   char tellerName[41];
   int matches;
