@@ -1,6 +1,10 @@
 /*
+ * $Source: /home/wms/cvs/cgoban/src/client/main.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2000/02/26 22:53:49 $
+ *
  * src/client/main.c, part of Complete Goban (game program)
- * Copyright (C) 1995-1996 William Shubert
+ * Copyright  1995-2000 William Shubert
  * See "configure.h.in" for more copyright information.
  */
 
@@ -17,8 +21,8 @@
 #include "../cgoban.h"
 #include "../msg.h"
 #include "../help.h"
-#ifdef  _CLIENT_cMAIN_H_
-        LEVELIZATION ERROR
+#ifdef _CLIENT_MAIN_H_
+#error LEVELIZATION ERROR
 #endif
 #include "main.h"
 
@@ -167,8 +171,6 @@ void  cliMain_activate(CliMain *cMain)  {
   cliConn_prompt(&cMain->data->conn);
   cliConn_send(&cMain->data->conn,
 	       "toggle quiet 0\ntoggle verbose 0\ngames\nwho\n");
-  if (cMain->data->server == cliServer_nngs)
-    cliConn_send(&cMain->data->conn, "client 5\n");
 }
 
 
