@@ -1,6 +1,10 @@
 /*
- * src/gmp/play.c, part of Complete Goban (game program)
- * Copyright (C) 1995-1996 William Shubert
+ * $Source: /home/wms/cvs/cgoban/src/gmp/play.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2000/02/09 06:50:05 $
+ *
+ * Part of Complete Goban (game program)
+ * Copyright  1995-1996,2000 William Shubert
  * See "configure.h.in" for more copyright information.
  *
  * Most of this file was mercilessly cut and pasted from local.c.  I probably
@@ -138,7 +142,6 @@ static GmpPlay  *gmpPlay_createSgf(Cgoban *cg, Sgf *mc,
   GoRules  rules;
   int  size, hcap;
   float  komi;
-  const char  *white = "Unknown", *black = "Unknown";
   GoTime  time;
   const char  *title;
   GoStone  s;
@@ -178,16 +181,6 @@ static GmpPlay  *gmpPlay_createSgf(Cgoban *cg, Sgf *mc,
   } else  {
     komi = 0.0;
   }
-  me = sgf_findFirstType(mc, sgfType_playerName);
-  while (me)  {
-    if (me->gVal == goStone_white)
-      white = str_chars(me->sVal);
-    else  {
-      assert(me->gVal == goStone_black);
-      black = str_chars(me->sVal);
-    }
-    me = sgfElem_findFirstType(me, sgfType_playerName);
-  }
   me = sgf_findFirstType(mc, sgfType_time);
   if (me)  {
     goTime_parseDescribeChars(&time, str_chars(me->sVal));
