@@ -1,6 +1,10 @@
 /*
+ * $Source: /home/wms/cvs/cgoban/src/goGame.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2000/02/26 23:03:46 $
+ *
  * src/gogame.c, part of Complete Goban (game program)
- * Copyright (C) 1995-1996 William Shubert.
+ * Copyright  1995-2000 William Shubert.
  * See "configure.h.in" for more copyright information.
  */
 
@@ -10,7 +14,7 @@
 #include <wms/str.h>
 #include "goBoard.h"
 #ifdef  _GOGAME_H_
-        LEVELIZATION ERROR
+#error LEVELIZATION ERROR
 #endif
 #include "goGame.h"
 
@@ -275,7 +279,7 @@ bool  goGame_isLegal(GoGame *game, GoStone moveColor, int move)  {
     return(FALSE);
     break;
   default:
-    assert(FALSE);
+    abort();
     break;
   }
 }
@@ -344,7 +348,7 @@ static bool  goGame_canMove(GoGame *game, GoStone s, int move)  {
     return(TRUE);
     break;
   default:
-    assert(FALSE);
+    abort();
     break;
   }
 }
