@@ -644,7 +644,7 @@ static ButOut newTime(ButTimer *t)  {
 void  goban_updateTimeReadouts(Goban *g)  {
   GoStone  color;
   Str  newText;
-  int tLeft, stonesLeft;
+  int tLeft;
 
   assert(MAGIC(g));
   str_init(&newText);
