@@ -41,19 +41,19 @@ static const AbutHelpText  aboutAuthor[] = {
    " have any comments about this program.  Bug reports are especially "
    "welcome.  As of the date at the top of this help page, you can contact "
    "me in these ways:"},
-  {butText_left, 0, "   Email: wms@hevanet.com"},
-  {butText_left, 0, "   WWW: http://www.hevanet.com/wms/"},
-  {butText_left, 0, "   Phone: (503)223-2285"},
+  {butText_left, 0, "   Email: wms@igoweb.org"},
+  {butText_left, 0, "   WWW: http://www.igoweb.org/~wms/"},
+  {butText_left, 0, "   Phone: 503-223-2285"},
   {butText_just, 0, "Or send me a postcard at:"},
   {butText_left, 0, "   Bill Shubert"},
-  {butText_left, 0, "   1812 NW Hoyt St."},
-  {butText_left, 0, "   Portland, OR 97209"},
+  {butText_left, 0, "   2014 NW Glisan St. #510"},
+  {butText_left, 0, "   Portland OR 97209"},
   {butText_left, 0, "   USA"},
   {butText_just, 0, ""},
   {butText_just, 0, "   Thanks for trying out my program.  I hope you like "
    "it!"},
   {butText_just, 0, "   Special thanks to all cgoban testers, especially "
-   "to Tomas Boman, Jean-Louis Martineau, "
+   "to Andries Brouwer, Tomas Boman, Jean-Louis Martineau, "
    "Eric Anderson, Dan Niles, Per-Eric Martin, Anthony Thyssen, "
    "Jan van der Steen, "
    "Eric Hoffman, Allen Tollin, Mel Melchner, Saito Takaaki, and "
