@@ -1,6 +1,10 @@
 /*
- * src/local.c, part of Complete Goban (game program)
- * Copyright (C) 1995-1996 William Shubert
+ * $Source: /home/wms/cvs/cgoban/src/local.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2000/02/09 06:50:02 $
+ *
+ * Part of Complete Goban (game program)
+ * Copyright  1995-1996,2000 William Shubert
  * See "configure.h.in" for more copyright information.
  */
 
@@ -342,7 +346,6 @@ static GobanOut  quitPressed(void *packet)  {
 static GobanOut  passPressed(void *packet)  {
   Local  *l = packet;
   GoGameState  oldState = l->game->state;
-  SgfElem  *startActive;
   GoStone  moveColor;
   bool  timeLeft;
 
@@ -350,7 +353,6 @@ static GobanOut  passPressed(void *packet)  {
   readGobanComments(l);
   moveColor = goGame_whoseMove(l->game);
   sgf_addNode(l->moves);
-  startActive = l->moves->active;
   if (oldState == goGameState_dispute)
     addDisputedTriangles(l->game, l->moves);
   sgf_pass(l->moves, moveColor);
